Astronomical dust extinction
============================

.. image:: http://readthedocs.org/projects/dust-extinction/badge/?version=latest
   :target: http://dust-extinction.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
	 
.. image:: https://travis-ci.org/karllark/dust_extinction.svg?branch=master
   :target: https://travis-ci.org/karllark/dust_extinction
   :alt: CI Testing Status

.. image:: https://coveralls.io/repos/github/karllark/dust_extinction/badge.svg?branch=master
   :target: https://coveralls.io/github/karllark/dust_extinction?branch=master
   :alt: Test Coverage Status
	    
.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge
    
This package provides astronomical interstellar dust extinction curves
implemented using the astropy.modeling framework.

This package is potentially an affiliated package of `AstroPy`_.

In Development!
---------------

This code is currently in active development.
Contributions welcome (see below).

Contributors
------------
Karl Gordon

Contributing
------------

Please open a new issue or new pull request for bugs, feedback, or new features
you would like to see.   If there is an issue you would like to work on, please
leave a comment and we will be happy to assist.   New contributions and
contributors are very welcome!

New to github or open source projects?  If you are unsure about where to start
or haven't used github before, please feel free to contact `@karllark`.
Want more information about how to make a contribution?  Take a look at
the astropy `contributing`_ and `developer`_ documentation.

Feedback and feature requests?   Is there something missing you would like
to see?  Please open an issue or send an email to  `@karllark`.
dust_extinction follows the `Astropy Code of Conduct`_ and strives to provide a
welcoming community to all of our users and contributors.

License
-------

This code is licensed under a 3-clause BSD style license (see the
``LICENSE.rst`` file).

.. _AstroPy: http://www.astropy.org/
.. _contributing: http://docs.astropy.org/en/stable/index.html#contributing
.. _developer: http://docs.astropy.org/en/stable/index.html#developer-documentation
.. _Astropy Code of Conduct:  http://www.astropy.org/about.html#codeofconduct
